@@ -33,6 +33,9 @@ from fabric import Connection as _Connection
 from fabric import connection
 from fabric.connection import opens
 
+# patch 
+from invoke.runners import Runner
+
 DEFAULT_MARIADB_PASSOWRD = os.environ.get(
     'DEFAULT_MARIADB_PASSOWRD', "SuXeMA3oTeXWgfjz2G1BGrPm0v0OKw")
 
@@ -45,6 +48,17 @@ DEPLOY_TEST_SERVER_USER = os.environ.get(
     'DEPLOY_TEST_SERVER_USER', 'nuwa')
 DEPLOY_TEST_SERVER_PASSWORD = os.environ.get(
     'DEPLOY_TEST_SERVER_PASSWORD', '@%)@5529')
+    
+_read_our_stdin = Runner.read_our_stdin
+
+def read_our_stdin(self, input_):
+    bytes_ = _read_our_stdin(self, input_)
+    if bytes_:
+        return bytes_
+    else:
+        return None
+        
+Runner.read_our_stdin = read_our_stdin
 
 def getConnectKwargs(password=None, key=os.path.join("PrivateKey.key")):
     # put key
@@ -129,6 +143,7 @@ def run(self, command, notRecord=False, **kwargs):
 
     .. versionadded:: 2.0
     """
+    print("AAA", kwargs)
     if "hide" in kwargs and kwargs["hide"] == True:
         pass
     else:
